{% raw %}
{% load mote_tags %}
{% mask element.json.data.Language_list_text as "language_text" %}
<div class="languages">
  <ul class="language-list language-list--text-decorated">
    {% for item in language_text.languages %}
        <li class="language-list__item language-list__item--text-decorated">{{ item.language }}</li>
    {% endfor %}
  </ul>
  <ul class="language-list language-list--text-decorated language-list--text-decorated-footer">
    <li class="language-list__item language-list--text-decorated language-list--text-decorated-footer">
      <span class="language-list--text-decorated__title language-list--text-decorated__title--footer">Languages</span>
    </li>
    {% for item in language_text.languages %}
        <li class="language-list__item language-list__item--text-decorated language-list__item--text-decorated-footer">{{ item.language }}</li>
    {% endfor %}
  </ul>
</div>
{% endraw %}
