{% raw %}
{% load mote_tags %}
<div class="teaser-meta-list">
  <div class="teaser-meta-list__comment-counter">12
    <span class="teaser-meta-list__comment-label-icon">comments</span>
  </div>
</div>
{% endraw %}
