.call-to-action {
  font-family: 'Quicksand', sans-serif;
  position: relative;
}
.call-to-action__item {
  font-size: 14px;
  padding: 10px 5px 0 0;
  margin: 10px 0;
  background: none;
  border: none;
  color: #000;
  display: block;
  font-weight: 700;
  text-align: left;
  text-decoration: underline;
  text-transform: uppercase;
  @media screen and (min-width: 320px) {
    background: #000;
    color: #fff;
    border-radius: 3px;
    padding: 10px;
    text-align: center;
    font-weight: normal;
    text-decoration: none;
  }
  [data-direction~="right"]:before,
  [data-direction~="left"]:after {
    color: #fff;
  }
}

/*
  Back/ Forward directional
  Home
*/
.call-to-action__item--text {
  background: none;
  color: #000;
  padding: 5px 0;
  text-align: left;
  font-weight: 700;
  text-decoration: underline;
  text-transform: inherit;
  display: block;
  &:hover {
    color: #686A6B;
  }
}
.call-to-action__item-text-upper {
  background: none;
  text-transform: uppercase;
  color: #000;
  @media screen and (min-width: 320px) {
    text-decoration: none;
  }
  &:hover {
    text-decoration: underline;
    color: #686A6B;
  }
}

/*
  Login
  Submit
  Reset
*/
.call-to-action__item-primary {
  display: block;
  margin: 5px 10px;
}

.call-to-action__item--secondary {
  font-weight: bold;
  @media screen and (min-width: 320px) {
    background: #fff;
    border: 1px solid #017AF5;
    color: blue;
    text-align: center;
    text-decoration: none;
    color: #017AF5;
  }
  &:hover {
    border-color: #686A6B;
  }
}


/*
  Used for search
*/
.call-to-action__item--with-icon {
  color: rgba(0, 0, 0, 0.5);
  border: none;
  font-size: 14px;
  padding: 5px  ;
  text-decoration: underline;
  text-transform: uppercase;
  @media screen and (min-width: 320px) {
    text-indent: -99em;
    height: 21px;
    width: 21px;
    position: absolute;
    right: 10%;
    top: 0;
  }
}

[data-direction~="right"]  {
  &:after {
    display: inline-block;
    padding-left: 10px;
    text-decoration: none !important;
    @media only screen and (min-width: 320px) {
      content: ">";
    }
    @media only screen and (min-width: 490px) {
      content: "❯";
    }
  }
}
[data-direction~="left"]  {
  &:before {
    display: inline-block;
    padding-right: 10px;
    text-decoration: none !important;
    @media only screen and (min-width: 320px) {
      content: "<";
    }
    @media only screen and (min-width: 490px) {
       content: "❮";
    }
  }
}
[data-state~="disabled"] {
  font-weight: bold;
  background-color: #D7DBDD;
}
