#header {
  background-color: #d3d3d3;
}
.header {
  position: relative;
  &__search {
    .header__search-input,
    .header__search-input + * {
      display: none;
    }
    .header__search-input:checked + * {
      display: block;
    }
    .header__search-bar {
      position: relative;
      display: block;
    }
    .call-to-action__item--with-icon,
    .call-to-action__nav-item--with-icon {
      color: #fff;
    }
  }
}
