.promoted-article-list__item--theme-headings {
    padding: 5px 0;
}
.promoted-article-list__desc-theme-headings {
  padding: 10px 15px;
}
.promoted-article-list__item--theme-headings {
  border-top-style: dotted;
  border-top-width: 1px;
  border-bottom: none;
}
