html, body  {
  background-color: #b7b9bc;
  margin: 0 auto;
  max-width: 35em;
  font-size: 16px;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  position: relative;
  @media (min-device-width: 320px) {
    max-width: 20em;
    font-family: 'Quicksand', sans-serif;
  }
}
body {
  background-color: #fff;
}

a {
  text-decoration: none;
  cursor: pointer;
  outline: none;
  &:hover {
    text-decoration: underline;
  }
}

h1,h2,h3,h4,h5,h6,p {
  margin: 0;
}

ul,li,ol {
  margin: 0;
}
