
/*
CORE STYLE OVERIDES
WAGTAIL ADMIN
*/
.wrapper {
  width: 100%;
}
@import "wagtail-admin/modules/_m-buttons";
@import "wagtail-admin/modules/_m-filter";
@import "wagtail-admin/modules/_m-results";
.content-wrapper {
  //Start Pagination
  .pagination {padding: 0 15px;}
  .pagination.col9 {
    width: 100%;
    p {padding: 15px 0 0;}
    ul {padding: 0 45px;}
  }
}

//COMMENT TABLE CONTENT
.submit-row .button {
  margin: 0 0 8px 0;
}

//640px
@media screen and (min-width: 50em) {
  //Left Sidebar
  .nav-wrapper {
    min-width: 12.6%;
    max-width: 180px;
    .inner {
      min-width: 12.6%;
      max-width: 180px;
    }
  }

  .content-wrapper {
    .pagination {
      padding: 0;
    }
  }
}
