//Content Wrapper Filter
.content-wrapper .changelist-filter {
  padding: 0;
  display: inline-block; //Override incorrect Bootstap
  width: 100%;
  h2, h3, ul, #date_range_filter {
    padding: 0 15px;
  }
}

@media screen and (min-width: 781px) {
  //Filter
  .content-wrapper .changelist-filter {
    float: right;
    width: auto;
  }
}
//640px or 800px Undo Styles
@media screen and (min-width: 50em) {
  //Filter
  .content-wrapper .changelist-filter {
    display: inline-block; //Override incorrect Bootstap
    float: none;
    width: 100%;
  }
}
@media screen and (min-width: 1200px) {
  //Filter
  .content-wrapper .changelist-filter {
    float: right;
    margin: 0 15px 0 5px;
    width: 18%; // This is getting overriden
    h2, h3, ul, #date_range_filter {
      padding: 0 5px 0 5px;
    }
  }
}
