{% load i18n %}

<ul class="menu-list menu-list--search-icon">
  <li class="menu-list__item menu-list__item--search-icon">
    <a href="#section_menu" class="menu-list__anchor menu-list__anchor-search-icon">{% trans "Menu" %}</a>
  </li>
  <li class="menu-list__item menu-list__item--search-icon">
    <a  href="#" class="menu-list__anchor menu-list__anchor-search-icon">{% trans "Sign up" %}</a>
  </li>
  <li id="search" class="menu-list__item menu-list__item--search-icon">
    <a href="#search-form" class="menu-list__anchor menu-list__anchor-search-icon">{% trans "Search" %}</a>
  </li>
</ul>
