{% extends "base.html" %}
{% load wagtailcore_tags wagtailimages_tags static core_tags %}
{% block content %}
  {% social_media_article %}
  {% include "patterns/components/articles/article-page_with_recommend-related.html" %}
  {% include "patterns/components/article-tags/sp_variations/tag_articles_block.html" %}
  {% include "patterns/basics/article-tags/article-tag.html" %}
{% endblock %}
